# Datasets

This folder contains some datasets to experiment with virocon.

The following files contain sea state data downloaded from the National Data Buoy Center (NDBC) (https://www.ndbc.noaa.gov):

- NDBC_buoy_46022.csv
- NDBC_buoy_46023.csv
- NDBC_buoy_46025.csv
- NDBC_buoy_46050.csv

Additionally there are two datasets that were used in a benchmarking exercise on environmental contours (see https://github.com/ec-benchmark-organizers/ec-benchmark):

 - ec-benchmark_dataset_A.txt contains 10 years of significant wave height (Hs) and zero-up-crossing period (Tz)
 - ec-benchmark_dataset_D.txt contains 25 years of wind speed (V) and significant wave height (Hs)


For the 3D environmental contour example, we use a 1-year dataset from coastDat-2 [1]_. The full 50-year environmental
dataset can also be downloaded here https://zenodo.org/record/5013306#.YTXUGi2201I :

 - coastDat2_oneyear.csv



.. [1] Groll, N. and Weisse, R.: A multi-decadal wind-wave hindcast for the North Sea 1949–2014: coastDat2, Earth Syst. Sci. Data, 9, 955–968, https://doi.org/10.5194/essd-9-955-2017, 2017.
